@@ -20,7 +20,6 @@ from .errors import (  # noqa
     CoordinatesTypeConversionError,
     DiffsFoundError,
     EyesError,
-    EyesIllegalArgument,
     NewTestError,
     OutOfBoundsError,
     TestFailedError,
@@ -48,14 +47,17 @@ from .selenium import StitchMode  # noqa
 from .server import FailureReports, SessionType  # noqa
 from .test_results import TestResultContainer, TestResults, TestResultsSummary  # noqa
 from .ultrafastgrid.config import (  # noqa
-    ChromeEmulationInfo,
     DeviceName,
-    EmulationDevice,
-    DesktopBrowserInfo,
-    RenderBrowserInfo,
+    ScreenOrientation,
+    IosDeviceName,
     ScreenOrientation,
 )
-from .ultrafastgrid.render import (  # noqa
+from .ultrafastgrid.render_browser_info import (
+    ChromeEmulationInfo,
+    DesktopBrowserInfo,
+    RenderBrowserInfo,
+)
+from .ultrafastgrid.render_request import (  # noqa
     RenderInfo,
     RenderingInfo,
     RenderRequest,
@@ -66,6 +68,12 @@ from .ultrafastgrid.render import (  # noqa
     VGResource,
     VisualGridSelector,
 )
+from .accessibility import (  # noqa
+    AccessibilityRegionType,
+    AccessibilitySettings,
+    AccessibilityLevel,
+    AccessibilityGuidelinesVersion,
+)
 
 __all__ = (
     logger.__all__  # noqa
@@ -85,7 +93,6 @@ __all__ = (
         "ChromeEmulationInfo",
         "DesktopBrowserInfo",
         "DeviceName",
-        "EmulationDevice",
         "ScreenOrientation",
         "RenderInfo",
         "RenderingInfo",
@@ -96,5 +103,9 @@ __all__ = (
         "RunningRender",
         "VGResource",
         "VisualGridSelector",
+        "AccessibilityRegionType",
+        "AccessibilitySettings",
+        "AccessibilityLevel",
+        "AccessibilityGuidelinesVersion",
     )  # noqa
 )
