@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, List, overload
+from typing import TYPE_CHECKING, List, overload, Union, Text
 
 import attr
 
@@ -8,6 +8,7 @@ from applitools.common.utils import argument_guard
 from applitools.common.ultrafastgrid import (
     ChromeEmulationInfo,
     RenderBrowserInfo,
+    IRenderBrowserInfo,
     ScreenOrientation,
     EmulationBaseInfo,
     IosDeviceInfo,
@@ -35,9 +36,7 @@ class Configuration(ConfigurationBase):
     hide_caret = attr.ib(default=False)  # type: bool
 
     # Rendering Configuration
-    is_raise_exception_on = False  # type: bool
-    is_rendering_config = False  # type: bool
-    _browsers_info = attr.ib(init=False, factory=list)  # type: List[RenderBrowserInfo]
+    _browsers_info = attr.ib(init=False, factory=list)  # type: List[IRenderBrowserInfo]
 
     def set_force_full_page_screenshot(self, force_full_page_screenshot):
         # type: (bool) -> Configuration
@@ -65,17 +64,17 @@ class Configuration(ConfigurationBase):
         return self
 
     @overload  # noqa
-    def add_browser(self, render_info):
+    def add_browser(self, desktop_browser_info):
         # type: (DesktopBrowserInfo) -> Configuration
         pass
 
     @overload  # noqa
-    def add_browser(self, render_info):
+    def add_browser(self, ios_device_info):
         # type: (IosDeviceInfo) -> Configuration
         pass
 
     @overload  # noqa
-    def add_browser(self, render_info):
+    def add_browser(self, chrome_emulation_info):
         # type: (ChromeEmulationInfo) -> Configuration
         pass
 
@@ -84,44 +83,33 @@ class Configuration(ConfigurationBase):
         # type: (int, int, BrowserType) -> Configuration
         pass
 
+    @overload  # noqa
+    def add_browser(self, width, height, browser_type, baseline_env_name):
+        # type: (int, int, BrowserType, Text) -> Configuration
+        pass
+
     def add_browser(self, *args):  # noqa
-        if isinstance(args[0], RenderBrowserInfo):
+        if isinstance(args[0], IRenderBrowserInfo):
             self._browsers_info.append(args[0])
-        if isinstance(args[0], IosDeviceInfo):
-            self._browsers_info.append(RenderBrowserInfo(ios_device_info=args[0]))
-        elif isinstance(args[0], EmulationBaseInfo):
-            self._browsers_info.append(RenderBrowserInfo(emulation_info=args[0]))
         elif (
             isinstance(args[0], int)
             and isinstance(args[1], int)
             and isinstance(args[2], BrowserType)
         ):
+            if len(args) == 4:
+                baseline_env_name = args[3]
+            else:
+                baseline_env_name = self.baseline_env_name
             self._browsers_info.append(
-                RenderBrowserInfo(
-                    RectangleSize(args[0], args[1]), args[2], self.baseline_env_name
-                )
+                DesktopBrowserInfo(args[0], args[1], args[2], baseline_env_name)
             )
         else:
             raise ValueError("Unsupported parameters")
         return self
 
-    @overload  # noqa
-    def add_browsers(self, *render_info):
-        # type: (*DesktopBrowserInfo) -> Configuration
-        pass
-
-    @overload  # noqa
-    def add_browsers(self, *ios_info):
-        # type: (*IosDeviceInfo) -> Configuration
-        pass
-
-    @overload  # noqa
-    def add_browsers(self, emulation_info):
-        # type: (*ChromeEmulationInfo) -> Configuration
-        pass
-
-    def add_browsers(self, *args):
-        for render_info in args:
+    def add_browsers(self, *renders_info):
+        # type:(*Union[DesktopBrowserInfo,IosDeviceInfo,ChromeEmulationInfo])->Configuration
+        for render_info in renders_info:
             self.add_browser(render_info)
         return self
 
@@ -137,8 +125,9 @@ class Configuration(ConfigurationBase):
         if self._browsers_info:
             return self._browsers_info
         if self.viewport_size:
-            browser_info = RenderBrowserInfo(
-                viewport_size=self.viewport_size,
+            browser_info = DesktopBrowserInfo(
+                width=self.viewport_size["width"],
+                height=self.viewport_size["height"],
                 browser_type=BrowserType.CHROME,
                 baseline_env_name=self.baseline_env_name,
             )
